@@ -1,6 +1,7 @@
 import pytest
 
 from sacrerouge.common.testing.metric_test_cases import ReferenceBasedMetricTestCase
+from sacrerouge.common.testing.util import sacrerouge_command_exists
 from sacrerouge.metrics import MoverScore
 from sacrerouge.metrics.moverscore import MOVERSCORE_INSTALLED
 
@@ -29,3 +30,9 @@ class TestMoverScore(ReferenceBasedMetricTestCase):
     def test_moverscore_order_invariant(self):
         metric = MoverScore()
         self.assert_order_invariant(metric)
+
+    def test_command_exists(self):
+        assert sacrerouge_command_exists(['moverscore'])
+
+    def test_setup_command_exists(self):
+        assert sacrerouge_command_exists(['setup-metric', 'moverscore'])
\ No newline at end of file
